#ifndef _kYSEC_BWLIST_H
#define _kYSEC_BWLIST_H

enum data_source_type
{
    KYSEC_SYS_SEC_TOOL = 0, //系统安全工具
    KYSEC_SEC_KIT_SDK,      //安全套件SDK
    KYSEC_COMM_KIT_SDK,     //通用安全SDK
    KYSEC_FINALLY_STATUS   //获取最终生效状态
};

#ifdef __cplusplus
extern "C" {
#endif

/*
 * 添加一个黑白名单节点信息到xml文件中
 * @bw_value:   黑名单或白名单节点("white" or "black", 其它值不合法)
 * @rpm_name:    添加到黑名单或者白名单的包名
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值:      0:成功，-1:出错, 1：软件包已经在列表
 */
int kysec_bwlist_add_kdk(char *bw_value, char *rpm_name, int data_source_type, char *data_source_name);

/*
 * 删除一个黑白名单节点信息
 * @bw_value:   黑名单或白名单节点("white" or "black", 其它值不合法)
 * @rpm_name:    删除黑名单或者白名单的包名
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值:      0:成功，-1:出错，1:不存在;
 */
int kysec_bwlist_del_kdk(char *bw_value, char *rpm_name, int data_source_type, char *data_source_name);

/*
 * 获取黑白名开关标识
 * @data_source_type: 数据源类型
 * 返回值：0:未开启黑白名单，1：开启白名单，2：开启黑名单, 3: 黑白名单都开启, -1: 失败
 */
int kysec_bwlist_get_root_distinguish_kdk(int data_source_type, char *data_source_name);

/*
 * 设置黑白名开关标识
 * @value: 0:不开启黑白名单，1：开启白名单，2：开启黑名单， 其它值非法
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值：0:成功，-1:失败
 */
int kysec_bwlist_set_root_distinguish_kdk(int bw_switch, int data_source_type, char *data_source_name);

/*
 * 判断软件包是否在黑名单、白名单中
 * @bw_value: 黑名单节点或者白名单节点("white" or "black"), 如果黑白名单都开启填(bwlist, 仅限data_source_type=3时使用)
 * rpm_name: 黑名单或者白名单的包名
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值：0: 不在名单中, 1: 在名单中, 2: 可以安装, 3: 拒绝安装, -1: 失败
 */
int kysec_bwlist_select_by_rpm_name_kdk(char *bw_value, char *rpm_name, int data_source_type, char *data_source_name);

/*
 * 根据数据库源类型清空策略
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值：0:成功，-1:失败
 */
int kysec_bwlist_clear_policy_kdk(int data_source_type, char *data_source_name);

#ifdef __cplusplus
}
#endif

#endif // _kYSEC_BWLIST_H