#ifndef _kYSEC_PBLK_H
#define _kYSEC_PBLK_H

#include <limits.h>

#define XML_HASH_SIZE	64

struct kysec_pblk_kernel {
	char path[PATH_MAX];
	char hash[XML_HASH_SIZE + 1];
};

#ifdef __cplusplus
extern "C" {
#endif

/**
 * 获取文件路径的hash值
 */
char *kysec_pblk_get_path_hash(const char *filepath);

/**
 * 添加一个程序信息节点到xml文件
 * @path: 程序路径
 * 返回值: 0：成功，1：包含该path的节点已经存在，-1：出错
 */
int kysec_pblk_add(char *path);

/**
 * 添加一个程序信息节点到xml文件
 * @path: 程序路径
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值: 0：成功，1：包含该path的节点已经存在，-1：出错
 */
int kysec_pblk_add_kdk(char *path, int data_source_type, char *data_source_name);

/** 
 * 从xml文件中删除一个节点
 * @path: 程序路径
 * 返回值: 0:成功，-1:出错
 */
int kysec_pblk_remove(char *path);

/** 
 * 从xml文件中删除一个节点
 * @path: 程序路径
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值: 0:成功，-1:出错
 */
int kysec_pblk_remove_kdk(char *path, int data_source_type, char *data_source_name);

/**
 * 获取指定路径path在xml文件中的节点数据
 */
struct kysec_pblk_kernel *kysec_pblk_read_node_with_path(char *filepath);

/**
 * 获取指定路径path在xml文件中的节点数据
 * @filepath: 程序路径
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值: 成功: 返回包含文件路径hash值的结构体, 须释放, 失败: 返回NULL
 */
struct kysec_pblk_kernel *kysec_pblk_read_node_with_path_kdk(char *filepath, int data_source_type, char *data_source_name);

/**
 * 获取指定hash在xml文件中的节点数据
 * @hash: 程序路径的hash
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值: 成功: 返回包含文件路径hash值的结构体, 须释放, 失败: 返回NULL
 */
struct kysec_pblk_kernel *kysec_pblk_read_node_with_hash_kdk(char *hash, int data_source_type, char *data_source_name);

/**
 * 获取xml文件中所有节点数据
 * 返回值: kysec_pblk_kernel指针数组，大小为@count
 */
struct kysec_pblk_kernel *kysec_pblk_read_all_data(int *count);

/**
 * kdk: 获取xml文件中所有节点数据
 * @data_source_type: 数据源类型
 * @data_source_name: 数据源名称
 * 返回值: kysec_pblk_kernel指针数组，大小为@count
 */
struct kysec_pblk_kernel *kysec_pblk_read_all_data_kdk(int data_source_type, const char *data_source_name, int *count);

/**
 * 获取 pblk.conf 中 action 的值，调用后需释放 action
 */
int kysec_pblk_get_action(char **action);


/**
 * 根据路径获取相同节点数
 * hash: 程序路径的hash
 * count: 相同节点计数，大于或者等于2就返回了
 * 返回值: 0: 成功, -1: 查询失败
 */
int kysec_pblk_get_same_node_by_hash(char *hash, int *count);

#ifdef __cplusplus
}
#endif

#endif // _kYSEC_PBLK_H
